@@ -1,21 +1,27 @@
-from ast_monitor.model import AST
-from ast_monitor.classes import SensorData, Interval
+from ast_monitor.basic_data import BasicData
 from ast_monitor.digital_twin import DigitalTwin
 from ast_monitor.gps_sensor import GpsSensor
 from ast_monitor.hr_sensor import HrSensor
-from ast_monitor.simulation import Simulation
+from ast_monitor.interval_training import IntervalTraining
 from ast_monitor.mainwindow import Ui_MainWindow
+from ast_monitor.model import AST
+from ast_monitor.simulation import Simulation
+from ast_monitor.training_session import TrainingSession
+from ast_monitor.write_log import WriteLog
+
 
 __all__ = [
-    AST,
-    SensorData,
-    Interval,
+    BasicData,
     DigitalTwin,
     GpsSensor,
     HrSensor,
+    IntervalTraining,
+    Ui_MainWindow,
+    AST,
     Simulation,
-    Ui_MainWindow
+    TrainingSession,
+    WriteLog
 ]
 
 __project__ = 'ast_monitor'
-__version__ = '0.2.1'
+__version__ = '0.3.1'
