@@ -1,3 +1,6 @@
+import time
+
+
 class DigitalTwin:
     """
     Class that represents a digital twin that
@@ -14,7 +17,8 @@ class DigitalTwin:
         self,
         proposed_heart_rate: int,
         duration: int,
-        tick_time: float
+        tick_time: float,
+        basic_data
     ) -> None:
         """
         Initialization method of the DigitalTwin class.\n
@@ -30,8 +34,9 @@ class DigitalTwin:
         self.proposed_heart_rate = proposed_heart_rate
         self.predicted_duration = 60 * duration
         self.current_heart_rate = 0
-        self.current_duration = 0
+        self.start_time = time.time()
         self.expected_trackpoints = (60 * 1000 * duration) // tick_time
+        self.basic_data = basic_data
 
     def read_control_data(self) -> tuple:
         """
@@ -39,7 +44,15 @@ class DigitalTwin:
         Returns:
             tuple[int, float]: current heart rate, current duration
         """
-        return self.current_heart_rate, self.current_duration
+        # Reading the current heart rate.
+        hr = self.basic_data.current_heart_rate
+        if hr:
+            hr = int(hr)
+
+        # Calculating the current phase time.
+        phase_time = time.time() - self.start_time
+
+        return hr, phase_time
 
     def calculate_prediction(
         self,
@@ -88,7 +101,7 @@ class DigitalTwin:
         current_time = 0
         current_heart_rate = 0
         previous_heart_rate, previous_time = self.read_control_data()
-        average_heart_rate = 0
+        self.average_heart_rate = previous_heart_rate
         time_delta = 0
         self.minus, self.plus = 0, 0
 
@@ -96,12 +109,6 @@ class DigitalTwin:
             # Reading the current heart rate and the duration.
             current_heart_rate, current_time = self.read_control_data()
 
-            # Calculating the average heart rate and the time difference.
-            average_heart_rate = (
-                average_heart_rate +
-                (1 / n) * (self.current_heart_rate - average_heart_rate)
-            )
-
             time_delta = current_time - previous_time
             if time_delta == 0:
                 continue
@@ -109,23 +116,40 @@ class DigitalTwin:
             if self.predicted_duration - 1 <= current_time:
                 break
 
-            # Calculating the TRIMP difference.
-            trimp_delta = (
-                ((current_heart_rate - previous_heart_rate) / 2) * time_delta -
-                self.proposed_heart_rate * time_delta
-            )
+            if current_heart_rate and previous_heart_rate:
+                # Calculating the average heart rate and the time difference.
+                if self.average_heart_rate:
+                    self.average_heart_rate = (
+                        self.average_heart_rate +
+                        (1 / n) * (
+                            current_heart_rate - self.average_heart_rate
+                        )
+                    )
+                else:
+                    self.average_heart_rate = current_heart_rate
 
-            # Predicted heart rate calculation.
-            self.predicted_heart_rate = self.calculate_prediction(
-                trimp_delta,
-                average_heart_rate,
-                self.proposed_heart_rate,
-                self.predicted_duration - current_time,
-                self.expected_trackpoints
-            )
-            if self.predicted_heart_rate:
-                self.predicted_heart_rate = round(self.predicted_heart_rate)
+                # Calculating the TRIMP difference.
+                trimp_delta = (
+                    ((current_heart_rate - previous_heart_rate) / 2) *
+                    time_delta -
+                    self.proposed_heart_rate * time_delta
+                )
+
+                # Predicted heart rate calculation.
+                self.predicted_heart_rate = self.calculate_prediction(
+                    trimp_delta,
+                    self.average_heart_rate,
+                    self.proposed_heart_rate,
+                    self.predicted_duration - current_time,
+                    self.expected_trackpoints
+                )
+                if self.predicted_heart_rate:
+                    self.predicted_heart_rate = round(
+                        self.predicted_heart_rate
+                    )
+
+                n += 1
 
-            n += 1
             previous_time = current_time
             previous_heart_rate = current_heart_rate
+            time.sleep(0.5)
